package gov.cms.oce;

import com.mmm.his.cer.foundation.Processable;
import com.mmm.his.cer.foundation.exception.FoundationException;
import gov.cms.oce.api.OceClaimExecutor;
import gov.cms.oce.model.external.OceClaim;
import gov.cms.oce.model.external.OceLineItem;
import java.io.IOException;

/**
 * Executes the native java implementation of the component.
 * 
 * @author CMS
 * @version 1.0, 09/01/2022
 */
public class IoceComponent implements Processable<IoceClaim, IoceOption, IoceRuntimeOption> {

  private final OceClaimExecutor component;

  /**
   * A new component.
   *
   */
  public IoceComponent() {
    this(null);
  }

  /**
   * A new component.
   *
   * @param runtimeOptions The component runtime options.
   */
  public IoceComponent(IoceRuntimeOption runtimeOptions) {
    this.component = new OceClaimExecutor();
  }

  @Override
  public void process(IoceClaim inputAndOutput) throws FoundationException {
    this.component.processClaim(inputAndOutput.getModel());
  }

  @Override
  public void reconfigure(IoceRuntimeOption option) throws FoundationException {
    // Nothing to do
  }

  @Override
  public void close() throws IOException {
    // Nothing to do
  }

  public final String getApcDescription(String value, short version) {
    return this.component.getApcDescription(value, version);
  }

  public final String getApcDescription(OceLineItem line, short version) {
    return this.component.getApcDescription(line, version);
  }

  public final String getLatestApcDescription(String value) {
    return this.component.getLatestApcDescription(value);
  }

  public final String getLatestApcDescription(OceLineItem line) {
    return this.component.getLatestApcDescription(line);
  }

  public final String getClaimDispositionDescription(String value, short version) {
    return this.component.getClaimDispositionDescription(value, version);
  }

  public final String getClaimDispositionDescription(OceClaim claim, short version) {
    return this.component.getClaimDispositionDescription(claim, version);
  }

  public final String getLatestClaimDispositionDescription(String value) {
    return this.component.getLatestClaimDispositionDescription(value);
  }

  public final String getLatestClaimDispositionDescription(OceClaim claim) {
    return this.component.getLatestClaimDispositionDescription(claim);
  }

  public final String getClaimDispositionValueDescription(String claimDispositionId, String value, short version) {
    return this.component.getClaimDispositionValueDescription(claimDispositionId, value, version);
  }

  public final String getClaimDispositionValueDescription(String claimDispositionId, OceClaim claim, short version) {
    return this.component.getClaimDispositionValueDescription(claimDispositionId, claim, version);
  }

  public final String getLatestClaimDispositionValueDescription(String claimDispositionId, String value) {
    return this.component.getLatestClaimDispositionValueDescription(claimDispositionId, value);
  }

  public final String getLatestClaimDispositionValueDescription(String claimDispositionId, OceClaim claim) {
    return this.component.getLatestClaimDispositionValueDescription(claimDispositionId, claim);
  }

  public final String getClaimProcessedFlagDescription(String value, short version) {
    return this.component.getClaimProcessedFlagDescription(value, version);
  }

  public final String getClaimProcessedFlagDescription(OceClaim claim, short version) {
    return this.component.getClaimProcessedFlagDescription(claim, version);
  }

  public final String getLatestClaimProcessedFlagDescription(String value) {
    return this.component.getLatestClaimProcessedFlagDescription(value);
  }

  public final String getLatestClaimProcessedFlagDescription(OceClaim claim) {
    return this.component.getLatestClaimProcessedFlagDescription(claim);
  }

  public final String getDiscountFormulaDescription(String value, short version) {
    return this.component.getDiscountFormulaDescription(value, version);
  }

  public final String getDiscountFormulaDescription(OceLineItem line, short version) {
    return this.component.getDiscountFormulaDescription(line, version);
  }

  public final String getLatestDiscountFormulaDescription(String value) {
    return this.component.getLatestDiscountFormulaDescription(value);
  }

  public final String getLatestDiscountFormulaDescription(OceLineItem line) {
    return this.component.getLatestDiscountFormulaDescription(line);
  }

  public final String getDiagnosisDescription(String value, short version) {
    return this.component.getDiagnosisDescription(value, version);
  }

  public final String getLatestDiagnosisDescription(String value) {
    return this.component.getLatestDiagnosisDescription(value);
  }

  public final String getEditDescription(String value, short version) {
    return this.component.getEditDescription(value, version);
  }

  public final String getLatestEditDescription(String value) {
    return this.component.getLatestEditDescription(value);
  }

  public final String getEditDispositionDescription(String value, short version) {
    return this.component.getEditDispositionDescription(value, version);
  }

  public final String getLatestEditDispositionDescription(String value) {
    return this.component.getLatestEditDispositionDescription(value);
  }

  public final String getErrorDescription(String value, short version) {
    return this.component.getErrorDescription(value, version);
  }

  public final String getLatestErrorDescription(String value) {
    return this.component.getLatestErrorDescription(value);
  }

  public final String getHcpcsDescription(String value, short version) {
    return this.component.getHcpcsDescription(value, version);
  }

  public final String getLatestHcpcsDescription(String value) {
    return this.component.getLatestHcpcsDescription(value);
  }

  public final String getLineItemActionFlagDescription(String value, short version) {
    return this.component.getLineItemActionFlagDescription(value, version);
  }

  public final String getLatestLineItemActionFlagDescription(String value) {
    return this.component.getLatestLineItemActionFlagDescription(value);
  }

  public final String getLineItemRejectionDenialFlagDescription(String value, short version) {
    return this.component.getLineItemRejectionDenialFlagDescription(value, version);
  }

  public final String getLatestLineItemRejectionDenialFlagDescription(String value) {
    return this.component.getLatestLineItemRejectionDenialFlagDescription(value);
  }

  public final String getHcpcsModifierDescription(String value, short version) {
    return this.component.getHcpcsModifierDescription(value, version);
  }

  public final String getLatestHcpcsModifierDescription(String value) {
    return this.component.getLatestHcpcsModifierDescription(value);
  }

  public final String getPaymentAdjustmentFlagDescription(String value, short version) {
    return this.component.getPaymentAdjustmentFlagDescription(value, version);
  }

  public final String getLatestPaymentAdjustmentFlagDescription(String value) {
    return this.component.getLatestPaymentAdjustmentFlagDescription(value);
  }

  public final String getPaymentIndicatorDescription(String value, short version) {
    return this.component.getPaymentIndicatorDescription(value, version);
  }

  public final String getLatestPaymentIndicatorDescription(String value) {
    return this.component.getLatestPaymentIndicatorDescription(value);
  }

  public final String getPackagingFlagDescription(String value, short version) {
    return this.component.getPackagingFlagDescription(value, version);
  }

  public final String getLatestPackagingFlagDescription(String value) {
    return this.component.getLatestPackagingFlagDescription(value);
  }

  public final String getPaymentMethodFlagDescription(String value, short version) {
    return this.component.getPaymentMethodFlagDescription(value, version);
  }

  public final String getLatestPaymentMethodFlagDescription(String value) {
    return this.component.getLatestPaymentMethodFlagDescription(value);
  }

  public final String getRevenueCodeDescription(String value, short version) {
    return this.component.getRevenueCodeDescription(value, version);
  }

  public final String getLatestRevenueCodeDescription(String value) {
    return this.component.getLatestRevenueCodeDescription(value);
  }

  public final String getStatusIndicatorDescription(String value, short version) {
    return this.component.getStatusIndicatorDescription(value, version);
  }

  public final String getLatestStatusIndicatorDescription(String value) {
    return this.component.getLatestStatusIndicatorDescription(value);
  }

  public final String getValueCodeDescription(String value, short version) {
    return this.component.getValueCodeDescription(value, version);
  }

  public final String getLatestValueCodeDescription(String value) {
    return this.component.getLatestValueCodeDescription(value);
  }

}
